<?php

/**
 * This is the model class for table "{{solicitud_reservacion_desglose}}".
 *
 * The followings are the available columns in table '{{solicitud_reservacion_desglose}}':
 * @property string $id_desglose
 * @property string $id_reservacion
 * @property double $precio_adulto
 * @property double $precio_ninio
 * @property string $num_adultos
 * @property double $num_ninios
 * @property integer $num_jrs
 * @property integer $estatus
 * @property string $log
 * @property string $id_base_habitacion
 * @property string $id_tipo_habitacion
 * @property string $desgloseBeds
 */
class SolicitudReservacionDesglose extends CActiveRecord
{
	/**
	 * Returns the static model of the specified AR class.
	 * @param string $className active record class name.
	 * @return SolicitudReservacionDesglose the static model class
	 */
	public static function model($className=__CLASS__)
	{
		return parent::model($className);
	}

	/**
	 * @return string the associated database table name
	 */
	public function tableName()
	{
		return '{{solicitud_reservacion_desglose}}';
	}

	/**
	 * @return array validation rules for model attributes.
	 */
	public function rules()
	{
		// NOTE: you should only define rules for those attributes that
		// will receive user inputs.
		return array(
			array('id_reservacion', 'required'),
			array('num_jrs, estatus', 'numerical', 'integerOnly'=>true),
			array('precio_adulto, precio_ninio, num_ninios', 'numerical'),
			array('id_reservacion, num_adultos, id_base_habitacion, id_tipo_habitacion', 'length', 'max'=>10),
			// The following rule is used by search().
			// Please remove those attributes that should not be searched.
			array('id_desglose, id_reservacion, precio_adulto, precio_ninio, num_adultos, num_ninios, num_jrs, estatus, log, id_base_habitacion, id_tipo_habitacion, desgloseBeds', 'safe', 'on'=>'search'),
		);
	}

	/**
	 * @return array relational rules.
	 */
	public function relations()
	{
	
		return array(
			'idbasehabitacion'=> array(self::BELONGS_TO, 'BaseHabitacion', 'id_base_habitacion'),

			'idHabitacion'=> array(self::BELONGS_TO, 'TipoHabitaciones', 'id_tipo_habitacion'),

			'iddesglosepersona'=> array(self::BELONGS_TO, 'SolicitudReservacionDesglosePersona', 'id_desglose_persona'),

			'idReservacion'=> array(self::BELONGS_TO, 'SolicitudReservacion', 'id_reservacion'),

		);
	}

	/**
	 * @return array customized attribute labels (name=>label)
	 */
	public function attributeLabels()
	{
		return array(
			'id_desglose' => 'Id Desglose',
			'id_reservacion' => 'Id Reservacion',
			'precio_adulto' => 'Precio Adulto',
			'precio_ninio' => 'Precio Ninio',
			'num_adultos' => 'Num Adultos',
			'num_ninios' => 'Num Ninios',
			'num_jrs' => 'Num Jrs',
			'estatus' => 'Estatus',
			'log' => 'Log',
			'id_base_habitacion' => 'Id Base Habitacion',
			'id_tipo_habitacion' => 'Id Tipo Habitacion',
			'desgloseBeds' => 'Desglose Beds',
		);
	}

	/**
	 * Retrieves a list of models based on the current search/filter conditions.
	 * @return CActiveDataProvider the data provider that can return the models based on the search/filter conditions.
	 */
	public function search()
	{
		// Warning: Please modify the following code to remove attributes that
		// should not be searched.

		$criteria=new CDbCriteria;

		$criteria->compare('id_desglose',$this->id_desglose,true);
		$criteria->compare('id_reservacion',$this->id_reservacion,true);
		$criteria->compare('precio_adulto',$this->precio_adulto);
		$criteria->compare('precio_ninio',$this->precio_ninio);
		$criteria->compare('num_adultos',$this->num_adultos,true);
		$criteria->compare('num_ninios',$this->num_ninios);
		$criteria->compare('num_jrs',$this->num_jrs);
		$criteria->compare('estatus',$this->estatus);
		$criteria->compare('log',$this->log,true);
		$criteria->compare('id_base_habitacion',$this->id_base_habitacion,true);
		$criteria->compare('id_tipo_habitacion',$this->id_tipo_habitacion,true);
		$criteria->compare('desgloseBeds',$this->desgloseBeds,true);

		return new CActiveDataProvider($this, array(
			'criteria'=>$criteria,
		));
	}
}